@@ -1,4 +1,4 @@
-/* $Id: blast_util.c,v 1.133 2010/07/27 18:24:31 kazimird Exp $
+/* $Id: blast_util.c,v 1.134 2011/04/11 14:54:31 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -34,7 +34,7 @@
 
 #ifndef SKIP_DOXYGEN_PROCESSING
 static char const rcsid[] = 
-    "$Id: blast_util.c,v 1.133 2010/07/27 18:24:31 kazimird Exp $";
+    "$Id: blast_util.c,v 1.134 2011/04/11 14:54:31 kazimird Exp $";
 #endif /* SKIP_DOXYGEN_PROCESSING */
 
 #include <algo/blast/core/blast_util.h>
@@ -187,7 +187,7 @@ BlastSeqBlkSetSeqRanges(BLAST_SequenceBlk* seq_blk,
                         SSeqRange* seq_ranges,
                         Uint4 num_seq_ranges,
                         Boolean copy_seq_ranges,
-                        Int4 mask_type)
+                        ESubjectMaskingType mask_type)
 {
     SSeqRange* tmp;
 
