@@ -65,8 +65,8 @@ static GbFeatName STATIC__ParFlat_GBQual_names[ParFlat_TOTAL_GBQUAL] = {
  {"tag_peptide", Class_text}, { "mating_type", Class_text},
  {"satellite", Class_text}, { "gene_synonym", Class_text},
  {"UniProtKB_evidence", Class_text}, {"haplogroup", Class_text},
- {"artificial_location", Class_none}, {"non_functional", Class_none},
- {"pseudogene", Class_none}
+ {"artificial_location", Class_text}, {"non_functional", Class_none},
+ {"pseudogene", Class_none}, {"mobile_element_type", Class_text}
 };
 
 NLM_EXTERN GbFeatNamePtr x_ParFlat_GBQual_names(void) {
@@ -95,7 +95,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -121,7 +120,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -145,7 +143,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -172,7 +169,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -201,7 +197,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -224,7 +219,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"conflict",  1, {
+   {"conflict", 1, {
       GBQUAL_citation, -1, -1, -1, -1}, 14,
      {
       GBQUAL_allele,
@@ -247,7 +242,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1}},
-   {"D-loop",  0, {-1, -1, -1, -1, -1}, 15,
+   {"D-loop", 0, {-1, -1, -1, -1, -1}, 15,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -257,7 +252,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -279,7 +273,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -296,7 +289,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1}},
-   {"enhancer",  0, {-1, -1, -1, -1, -1}, 17,
+   {"enhancer", 0, {-1, -1, -1, -1, -1}, 17,
      {
       GBQUAL_allele,
       GBQUAL_bound_moiety,
@@ -307,7 +300,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -332,7 +324,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -350,7 +341,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1}},
-   {"gap",  1, {
+   {"gap", 1, {
       GBQUAL_estimated_length, -1, -1, -1, -1}, 5,
      {
       GBQUAL_evidence,
@@ -374,7 +365,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -397,7 +387,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -427,7 +416,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -453,7 +441,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -480,7 +467,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -508,7 +494,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_note,
       GBQUAL_old_locus_tag,
@@ -520,7 +505,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"mat_peptide",  0, {-1, -1, -1, -1, -1}, 25,
+   {"mat_peptide", 0, {-1, -1, -1, -1, -1}, 25,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -535,7 +520,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene_synonym,
       GBQUAL_inference,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -551,7 +535,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"misc_binding",  1, {
+   {"misc_binding", 1, {
       GBQUAL_bound_moiety, -1, -1, -1, -1}, 16,
      {
       GBQUAL_allele,
@@ -563,7 +547,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -587,7 +570,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -602,7 +584,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1}},
-   {"misc_feature",  0, {-1, -1, -1, -1, -1}, 23,
+   {"misc_feature", 0, {-1, -1, -1, -1, -1}, 23,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -613,7 +595,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -642,7 +623,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -655,7 +635,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"misc_RNA",  0, {-1, -1, -1, -1, -1}, 23,
+   {"misc_RNA", 0, {-1, -1, -1, -1, -1}, 23,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -666,7 +646,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -685,7 +664,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1}},
-   {"misc_signal",  0, {-1, -1, -1, -1, -1}, 19,
+   {"misc_signal", 0, {-1, -1, -1, -1, -1}, 19,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -696,7 +675,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -711,7 +689,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1}},
-   {"misc_structure",  0, {-1, -1, -1, -1, -1}, 17,
+   {"misc_structure", 0, {-1, -1, -1, -1, -1}, 17,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -722,7 +700,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -735,7 +712,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"modified_base",  1, {
+   {"modified_base", 1, {
       GBQUAL_mod_base, -1, -1, -1, -1}, 15,
      {
       GBQUAL_allele,
@@ -747,7 +724,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -758,7 +734,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"mRNA",  0, {-1, -1, -1, -1, -1}, 25,
+   {"mRNA", 0, {-1, -1, -1, -1, -1}, 25,
      {
       GBQUAL_allele,
       GBQUAL_artificial_location,
@@ -770,7 +746,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -789,7 +764,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"mutation",  0, {-1, -1, -1, -1, -1}, 18,
+   {"mutation", 0, {-1, -1, -1, -1, -1}, 18,
      {
       GBQUAL_citation,
       GBQUAL_db_xref,
@@ -799,7 +774,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -814,7 +788,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1}},
-   {"N_region",  0, {-1, -1, -1, -1, -1}, 18,
+   {"N_region", 0, {-1, -1, -1, -1, -1}, 18,
      {
       GBQUAL_citation,
       GBQUAL_db_xref,
@@ -823,7 +797,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -839,7 +812,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1}},
-   {"ncRNA",  1, {
+   {"ncRNA", 1, {
       GBQUAL_ncRNA_class, -1, -1, -1, -1}, 23,
      {
       GBQUAL_allele,
@@ -851,7 +824,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -903,7 +875,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_experiment,
       GBQUAL_function,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_map,
       GBQUAL_non_functional,
       GBQUAL_note,
@@ -929,7 +900,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -957,7 +927,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -979,7 +948,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -991,7 +959,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1}},
-   {"precursor_RNA",  0, {-1, -1, -1, -1, -1}, 20,
+   {"precursor_RNA", 0, {-1, -1, -1, -1, -1}, 20,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1002,7 +970,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -1018,7 +985,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1}},
-   {"prim_transcript",  0, {-1, -1, -1, -1, -1}, 18,
+   {"prim_transcript", 0, {-1, -1, -1, -1, -1}, 18,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1029,7 +996,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -1043,7 +1009,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1}},
-   {"primer_bind",  0, {-1, -1, -1, -1, -1}, 17,
+   {"primer_bind", 0, {-1, -1, -1, -1, -1}, 17,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1053,7 +1019,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -1067,7 +1032,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"promoter",  0, {-1, -1, -1, -1, -1}, 23,
+   {"promoter", 0, {-1, -1, -1, -1, -1}, 23,
      {
       GBQUAL_allele,
       GBQUAL_bound_moiety,
@@ -1079,7 +1044,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -1097,7 +1061,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1}},
-   {"protein_bind",  1, {
+   {"protein_bind", 1, {
       GBQUAL_bound_moiety, -1, -1, -1, -1}, 18,
      {
       GBQUAL_allele,
@@ -1109,7 +1073,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -1123,7 +1086,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1}},
-   {"RBS",  0, {-1, -1, -1, -1, -1}, 16,
+   {"RBS", 0, {-1, -1, -1, -1, -1}, 16,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1133,7 +1096,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -1146,7 +1108,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"repeat_region",  0, {-1, -1, -1, -1, -1}, 26,
+   {"repeat_region", 0, {-1, -1, -1, -1, -1}, 26,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1158,7 +1120,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene_synonym,
       GBQUAL_inference,
       GBQUAL_insertion_seq,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_mobile_element,
@@ -1178,7 +1139,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"repeat_unit",  0, {-1, -1, -1, -1, -1}, 21,
+   {"repeat_unit", 0, {-1, -1, -1, -1, -1}, 21,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1189,7 +1150,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -1206,7 +1166,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1}},
-   {"rep_origin",  0, {-1, -1, -1, -1, -1}, 17,
+   {"rep_origin", 0, {-1, -1, -1, -1, -1}, 17,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1217,7 +1177,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -1230,7 +1189,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"rRNA",  0, {-1, -1, -1, -1, -1}, 22,
+   {"rRNA", 0, {-1, -1, -1, -1, -1}, 22,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1241,7 +1200,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -1259,7 +1217,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1}},
-   {"S_region",  0, {-1, -1, -1, -1, -1}, 20,
+   {"S_region", 0, {-1, -1, -1, -1, -1}, 20,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1269,7 +1227,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -1286,7 +1243,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1}},
-   {"satellite",  0, {-1, -1, -1, -1, -1}, 21,
+   {"satellite", 0, {-1, -1, -1, -1, -1}, 21,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1296,7 +1253,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -1314,7 +1270,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1}},
-   {"scRNA",  0, {-1, -1, -1, -1, -1}, 21,
+   {"scRNA", 0, {-1, -1, -1, -1, -1}, 21,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1325,7 +1281,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -1353,7 +1308,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -1370,7 +1324,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1}},
-   {"snoRNA",  0, {-1, -1, -1, -1, -1}, 21,
+   {"snoRNA", 0, {-1, -1, -1, -1, -1}, 21,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1381,7 +1335,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -1398,7 +1351,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1}},
-   {"snRNA",  0, {-1, -1, -1, -1, -1}, 21,
+   {"snRNA", 0, {-1, -1, -1, -1, -1}, 21,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1409,7 +1362,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -1458,7 +1410,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_isolation_source,
       GBQUAL_kinetoplast,
       GBQUAL_lab_host,
-      GBQUAL_label,
       GBQUAL_lat_lon,
       GBQUAL_macronuclear,
       GBQUAL_map,
@@ -1493,7 +1444,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_virion,
       GBQUAL_haplogroup,
       -1, -1}},
-   {"stem_loop",  0, {-1, -1, -1, -1, -1}, 18,
+   {"stem_loop", 0, {-1, -1, -1, -1, -1}, 18,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1504,7 +1455,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -1518,7 +1468,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1}},
-   {"STS",  0, {-1, -1, -1, -1, -1}, 16,
+   {"STS", 0, {-1, -1, -1, -1, -1}, 16,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1528,7 +1478,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -1541,7 +1490,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"TATA_signal",  0, {-1, -1, -1, -1, -1}, 15,
+   {"TATA_signal", 0, {-1, -1, -1, -1, -1}, 15,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1551,7 +1500,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -1563,7 +1511,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"terminator",  0, {-1, -1, -1, -1, -1}, 17,
+   {"terminator", 0, {-1, -1, -1, -1, -1}, 17,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1573,7 +1521,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -1587,7 +1534,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"tmRNA",  0, {-1, -1, -1, -1, -1}, 23,
+   {"tmRNA", 0, {-1, -1, -1, -1, -1}, 23,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1598,7 +1545,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -1617,7 +1563,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1}},
-   {"transit_peptide",  0, {-1, -1, -1, -1, -1}, 21,
+   {"transit_peptide", 0, {-1, -1, -1, -1, -1}, 21,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1628,7 +1574,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -1645,7 +1590,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1}},
-   {"tRNA",  0, {-1, -1, -1, -1, -1}, 24,
+   {"tRNA", 0, {-1, -1, -1, -1, -1}, 24,
      {
       GBQUAL_allele,
       GBQUAL_anticodon,
@@ -1657,7 +1602,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -1676,7 +1620,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1}},
-   {"unsure",  0, {-1, -1, -1, -1, -1}, 15,
+   {"unsure", 0, {-1, -1, -1, -1, -1}, 15,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1686,7 +1630,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -1698,7 +1641,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"V_region",  0, {-1, -1, -1, -1, -1}, 20,
+   {"V_region", 0, {-1, -1, -1, -1, -1}, 20,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1708,7 +1651,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -1725,7 +1667,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1}},
-   {"V_segment",  0, {-1, -1, -1, -1, -1}, 20,
+   {"V_segment", 0, {-1, -1, -1, -1, -1}, 20,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1735,7 +1677,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_non_functional,
@@ -1752,7 +1693,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1}},
-   {"variation",  0, {-1, -1, -1, -1, -1}, 21,
+   {"variation", 0, {-1, -1, -1, -1, -1}, 21,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1764,7 +1705,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -1780,7 +1720,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1}},
-   {"3'clip",  0, {-1, -1, -1, -1, -1}, 18,
+   {"3'clip", 0, {-1, -1, -1, -1, -1}, 18,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1791,7 +1731,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -1805,7 +1744,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1}},
-   {"3'UTR",  0, {-1, -1, -1, -1, -1}, 18,
+   {"3'UTR", 0, {-1, -1, -1, -1, -1}, 18,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1816,7 +1755,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -1830,7 +1768,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1}},
-   {"5'clip",  0, {-1, -1, -1, -1, -1}, 18,
+   {"5'clip", 0, {-1, -1, -1, -1, -1}, 18,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1841,7 +1779,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -1855,7 +1792,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1}},
-   {"5'UTR",  0, {-1, -1, -1, -1, -1}, 18,
+   {"5'UTR", 0, {-1, -1, -1, -1, -1}, 18,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1866,7 +1803,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -1880,7 +1816,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1}},
-   {"-10_signal",  0, {-1, -1, -1, -1, -1}, 17,
+   {"-10_signal", 0, {-1, -1, -1, -1, -1}, 17,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1890,7 +1826,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -1904,7 +1839,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"-35_signal",  0, {-1, -1, -1, -1, -1}, 17,
+   {"-35_signal", 0, {-1, -1, -1, -1, -1}, 17,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1914,7 +1849,6 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_gene,
       GBQUAL_gene_synonym,
       GBQUAL_inference,
-      GBQUAL_label,
       GBQUAL_locus_tag,
       GBQUAL_map,
       GBQUAL_note,
@@ -1927,7 +1861,35 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1}}
+      -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"mobile_element", 1, {
+      GBQUAL_mobile_element_type, -1, -1, -1, -1}, 21,
+     {
+      GBQUAL_allele,
+      GBQUAL_citation,
+      GBQUAL_db_xref,
+      GBQUAL_evidence,
+      GBQUAL_experiment,
+      GBQUAL_function,
+      GBQUAL_gene,
+      GBQUAL_gene_synonym,
+      GBQUAL_inference,
+      GBQUAL_insertion_seq,
+      GBQUAL_locus_tag,
+      GBQUAL_map,
+      GBQUAL_note,
+      GBQUAL_old_locus_tag,
+      GBQUAL_partial,
+      GBQUAL_rpt_family,
+      GBQUAL_rpt_type,
+      GBQUAL_standard_name,
+      GBQUAL_transposon,
+      GBQUAL_usedin,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+      -1, -1, -1, -1}}
 };
 
 NLM_EXTERN SematicFeatPtr x_ParFlat_GBFeat(void) {
