@@ -29,7 +29,7 @@
 *   
 * Version Creation Date: 4/1/91
 *
-* $Revision: 6.58 $
+* $Revision: 6.60 $
 *
 * File Description:  Sequence Utilities for objseq and objsset
 *
@@ -608,7 +608,7 @@ NLM_EXTERN Boolean SeqLocRevCmp(SeqLocPtr anp);
 NLM_EXTERN Int4 GetOffsetInLoc(SeqLocPtr of, SeqLocPtr in, Uint1 which_end);
 NLM_EXTERN Int4 GetOffsetInBioseq(SeqLocPtr of, BioseqPtr in, Uint1 which_end);
 NLM_EXTERN Int4 GetOffsetInBioseqEx (SeqLocPtr of, BioseqPtr in, Uint1 which_end, Boolean is_circular);
-NLM_EXTERN void GetLeftAndRightOffsetsInBioseq (SeqLocPtr of, BioseqPtr in, Int4Ptr left, Int4Ptr right, Boolean is_circular);
+NLM_EXTERN void GetLeftAndRightOffsetsInBioseq (SeqLocPtr of, BioseqPtr in, Int4Ptr left, Int4Ptr right, Boolean is_circular, BoolPtr left_flip, BoolPtr right_flip );
 NLM_EXTERN Int2 SeqLocOrder(SeqLocPtr a, SeqLocPtr b, BioseqPtr in);
 
 NLM_EXTERN Int2 SeqLocMol(SeqLocPtr seqloc);
@@ -633,7 +633,9 @@ NLM_EXTERN Int2 SeqLocCompare(SeqLocPtr a, SeqLocPtr b);
 #define SLC_B_IN_A 2
 #define SLC_A_EQ_B 3
 #define SLC_A_OVERLAP_B 4
+NLM_EXTERN Int2 SeqLocCompareEx (SeqLocPtr a, SeqLocPtr b, Boolean compare_strand);
 
+NLM_EXTERN Boolean UnitTestSeqLocCompare (void);
 
 /*****************************************************************************
 *
