@@ -29,7 +29,7 @@
 *
 * Version Creation Date:   7/15/95
 *
-* $Revision: 6.73 $
+* $Revision: 6.74 $
 *
 * File Description: 
 *
@@ -42,352 +42,6 @@
 * ==========================================================================
 */
 
-/*************************************
-*
- * $Log: wprint.c,v $
- * Revision 6.73  2006/07/13 17:06:39  bollin
- * use Uint4 instead of Uint2 for itemID values
- * removed unused variables
- * resolved compiler warnings
- *
- * Revision 6.72  2005/01/12 22:53:04  vakatov
- * /htbin-post/Taxonomy/wgetorg -> /Taxonomy/Browser/wwwtax.cgi
- * /htbin-post/Taxonomy/wprintgc -> /Taxonomy/Utils/wprintgc.cgi
- *
- * Revision 6.71  2002/08/08 14:00:37  kans
- * added FANTOM_DB hyperlink
- *
- * Revision 6.70  2002/07/24 21:08:47  kans
- * reverted ncbi URL
- *
- * Revision 6.69  2002/07/23 16:44:35  kans
- * changed www.ncbi.nlm.nih.gov to www.ncbi.nih.gov
- *
- * Revision 6.68  2002/06/21 15:38:34  kans
- * added GABI db_xref
- *
- * Revision 6.67  2002/06/18 21:00:00  kans
- * added ISFinder as legal db_xref with hotlink
- *
- * Revision 6.66  2002/05/06 22:20:49  kans
- * added IFO and JCM db_xref hotlinks
- *
- * Revision 6.65  2002/04/18 22:24:16  kans
- * added dbEST and dbSTS links
- *
- * Revision 6.64  2002/02/20 21:59:44  tatiana
- * IMGT/LIGM dbxref added
- *
- * Revision 6.63  2002/02/01 19:40:01  kans
- * MGD uses id=MGI: URL prefix, strips MGI: if in db_xref text
- *
- * Revision 6.62  2002/01/02 13:21:16  kans
- * added WormBase links
- *
- * Revision 6.61  2001/12/06 17:00:41  kans
- * TextSave takes size_t, not Int2, otherwise titin protein tries to allocate negative number
- *
- * Revision 6.60  2001/12/06 12:36:41  kans
- * switch from viewer.cgi to viewer.fcgi
- *
- * Revision 6.59  2001/11/27 18:45:16  kans
- * fixed FLYBASE capitalization, added niaEST
- *
- * Revision 6.58  2001/10/02 17:39:29  yaschenk
- * Removing memory leaks
- *
- * Revision 6.57  2001/08/06 23:59:45  kans
- * added third party annotation SeqID support
- *
- * Revision 6.56  2001/08/06 22:13:13  kans
- * using NUM_SEQID, added TPA ids to arrays
- *
- * Revision 6.55  2001/04/23 22:40:04  tatiana
- * estimated size increased in www_featkey()
- *
- * Revision 6.54  2001/04/12 22:31:37  yaschenk
- * fixing string size estimates in www_accession
- *
- * Revision 6.53  2001/02/01 16:23:09  tatiana
- * typo fixed in RGD link
- *
- * Revision 6.52  2001/01/03 17:01:44  tatiana
- * a bug fixed in LocGenomePrint, complement added
- *
- * Revision 6.51  2000/12/06 20:56:17  tatiana
- * AceView link added
- *
- * Revision 6.50  2000/12/05 23:04:37  tatiana
- * NT_ COMMENT formatted
- *
- * Revision 6.49  2000/12/05 01:22:18  tatiana
- * COG added
- *
- * Revision 6.47  2000/10/24 20:33:39  tatiana
- * added link to UniSTS and InterimID
- *
- * Revision 6.46  2000/10/18 21:19:59  kans
- * changed omim link
- *
- * Revision 6.45  2000/10/18 12:29:37  tatiana
- * rice link changed
- *
- * Revision 6.44  2000/09/05 18:22:48  kans
- * added CDD link
- *
- * Revision 6.43  2000/08/07 14:03:03  tatiana
- * printf format fix
- *
- * Revision 6.42  2000/07/25 14:40:37  tatiana
- * changed SGD link
- *
- * Revision 6.41  2000/07/20 21:22:36  tatiana
- * refseq hot link corrected
- *
- * Revision 6.40  2000/07/14 20:24:27  kans
- * added RGD as dbxref with web link
- *
- * Revision 6.39  2000/07/11 22:17:12  tatiana
- * fixed hot link for refseq
- *
- * Revision 6.38  2000/07/10 21:02:17  tatiana
- * added link to refseq
- *
- * Revision 6.37  2000/06/21 18:31:04  tatiana
- * fixed qmap.cgi syntax for dbsource link
- *
- * Revision 6.36  2000/03/23 14:45:53  tatiana
- * added links for MGD, FBgn, FBan
- *
- * Revision 6.35  2000/03/20 17:47:51  kans
- * changed rice link
- *
- * Revision 6.34  2000/03/09 22:16:56  kans
- * changed rice link
- *
- * Revision 6.33  2000/02/29 15:33:15  tatiana
- * RiceGenes URL changed
- *
- * Revision 6.32  2000/02/25 21:52:03  kans
- * changed flybase link to indiana university url
- *
- * Revision 6.31  2000/02/24 17:53:56  kans
- * added dbSNP and RATMAP to dbxref
- *
- * Revision 6.30  2000/01/11 17:14:13  tatiana
- * check for web symbols added in PrintComment
- *
- * Revision 6.29  1999/12/21 14:27:10  tatiana
- * version added to CONTIG line
- *
- * Revision 6.28  1999/11/02 19:57:04  tatiana
- * a typo fixed in PrintGenome
- *
- * Revision 6.27  1999/11/02 16:31:20  tatiana
- * fixed PrintGenome()
- *
- * Revision 6.26  1999/10/01 16:40:24  vakatov
- * Fixed a stack memory overrun bug in PrintDate()
- *
- * Revision 6.25  1999/09/29 17:20:38  tatiana
- * SeqIdFindBest changed to SeqIdSelect for CONTIG line
- *
- * Revision 6.24  1999/08/31 18:31:24  tatiana
- * OLDQUERY ifdef added
- *
- * Revision 6.23  1999/08/30 17:07:01  tatiana
- * minor changes for html version printing
- *
- * Revision 6.22  1999/05/13 23:00:44  tatiana
- * hot link added to REFSEQ in COMMENT
- *
- * Revision 6.21  1999/04/07 22:17:58  tatiana
- * added BR in web GARPHIK_FMT
- *
- * Revision 6.20  1999/04/07 20:49:18  tatiana
- * fix compiler warning www_protein_id()
- *
- * Revision 6.19  1999/04/06 22:37:14  tatiana
- * www_protein_id() added
- *
- * Revision 6.18  1999/04/06 14:56:57  tatiana
- * SWISS-PROT link disabled
- *
- * Revision 6.17  1999/04/06 14:41:44  tatiana
- * LocusLink corrections
- *
- * Revision 6.16  1999/03/30 21:02:18  tatiana
- * www_accession www_taxid added
- *
- * Revision 6.15  1999/03/29 18:15:33  tatiana
- * OMIM and LocusLink hyper-links added to dbxref
- *
- * Revision 6.14  1999/03/12 17:33:47  tatiana
- * www_featkey() added and type casting fixed
- *
- * Revision 6.13  1998/11/23 17:05:35  tatiana
- * a bug fixed in SP link in www_db_xref()
- *
- * Revision 6.12  1998/10/08 15:14:52  tatiana
- * link to SWISSPROT - expasy.hcuge.ch removed
- *
- * Revision 6.11  1998/08/19 18:42:08  tatiana
- * hot link to RiceGenes added
- *
- * Revision 6.10  1998/08/04 14:58:30  tatiana
- * ff_AddString changed to ff_AddStringWithTildes in www_PrintComment()
- *
- * Revision 6.9  1998/07/24 16:51:06  vakatov
- * added LIBCALL modifier to "www_PrintComment()"
- *
- * Revision 6.8  1998/07/23 22:41:52  tatiana
- * added www_PrintComment()
- *
- * Revision 6.7  1998/05/28 18:30:27  tatiana
- * typedef for HeadTailProc moved to ffprint.h
- *
- * Revision 6.6  1998/04/30 21:52:48  tatiana
- * *** empty log message ***
- *
- * Revision 6.5  1998/04/29 16:21:48  tatiana
- * www_dbsource(): db=n changed to db=s in query link
- *
- * Revision 6.4  1998/02/11 19:37:05  tatiana
- * check for NULL added in LocPrintGenome()
- *
- * Revision 6.3  1998/02/06 21:21:08  tatiana
- * db changed to s in query URL
- *
- * Revision 6.0  1997/08/25 18:08:38  madden
- * Revision changed to 6.0
- *
- * Revision 5.21  1997/08/19 22:34:18  tatiana
- * bug fixed in PrintGenome()
- *
- * Revision 5.19  1997/08/07 22:18:13  tatiana
- * PrintGenome() fix for the WWW
- *
- * Revision 5.18  1997/08/06 22:38:03  tatiana
- * minor fixes in PrintGenome()
- *
- * Revision 5.17  1997/07/28 14:31:31  vakatov
- * Keep the head_tail_ff() proto in-sync with its header-located declaration
- *
- * Revision 5.16  1997/07/28 13:29:38  ostell
- * Moved GetUniGeneIDForSeqId() to seqmgr.c
- *
- * Revision 5.15  1997/07/25 15:51:37  tatiana
- * sition counts in PrintGenome
- *
- * Revision 5.14  1997/07/16 21:26:32  tatiana
- * PrintGenome() added
- *
- * Revision 5.13  1997/06/26 20:56:43  tatiana
- * a bug fixed in PrintSPBlock
- *
- * Revision 5.12  1997/06/23 19:18:53  tatiana
- * www_featloc() fixed
- *
- * Revision 5.11  1997/06/19 18:39:57  vakatov
- * [WIN32,MSVC++]  Adopted for the "NCBIOBJ.LIB" DLL'ization
- *
- * Revision 5.10  1997/03/13 21:37:37  tatiana
- * query?-guid changed to query?uid in all Entrez limks
- *
- * Revision 5.9  1997/03/11  20:17:25  tatiana
- * OMIM hot links added to DBSOURCE
- *
- * Revision 5.8  1997/01/10  19:51:39  epstein
- * add missing LIBCALLs
- *
- * Revision 5.7  1997/01/06  21:38:52  vakatov
- * Removed local(static) NCBI_months[12] -- use that from the "ncbitime.[ch]"
- *
- * Revision 5.6  1996/12/03  15:50:43  tatiana
- * hot link to CK in db_xref added
- *
- * Revision 5.5  1996/08/16  20:35:44  tatiana
- * www_coded_by added
- *
- * Revision 5.4  1996/07/19  21:36:29  tatiana
- * protection for NULL acc added to PrintSPBlock()
- *
- * Revision 5.3  1996/07/19  18:13:16  tatiana
- * ddbj hot link bug fixed (gbj -> dbj)
- *
- * Revision 5.2  1996/07/12  19:49:52  tatiana
- * SP hot link added to db_xref
- *
- * Revision 5.1  1996/06/25  22:22:09  tatiana
- * new GDB hot list
- *
- * Revision 4.25  1996/04/29  19:54:11  tatiana
- * new SGD URL
- *
- * Revision 4.24  1996/04/15  16:08:36  tatiana
- * new line in DBSOURCE
- *
- * Revision 4.23  1996/04/15  14:37:43  tatiana
- * old_www_featloc removed
- *
- * Revision 4.21  1996/04/09  16:12:19  tatiana
- * *** empty log message ***
- *
- * Revision 4.20  1996/04/09  14:05:15  tatiana
- * DescrStructPtr changes
- *
- * Revision 4.18  1996/04/08  21:53:17  tatiana
- * change in www_featloc
- *
- * Revision 4.17  1996/03/27  15:40:55  epstein
- * re-retro previous 'referer' changes, and change swissprot output to point to protein DB
- *
- * Revision 4.16  1996/03/25  15:21:46  tatiana
- * www_featloc added
- *
- * Revision 4.15  1996/03/20  16:13:58  epstein
- * change print-logic to accomodate 'referer' script which logs references to external databases
- *
- * Revision 4.14  1996/02/28  04:53:06  ostell
- * minor fixes
- *
- * Revision 4.13  1996/02/26  03:45:24  ostell
- * fixed usage of GatherDescrListByChoice and changed function to allocate
- * first DescrStruct instead using static storage
- *
- * Revision 4.12  1996/02/26  00:46:18  ostell
- * removed unused local variables and integer size mismatch fusses
- *
- * Revision 4.11  1996/02/21  20:08:03  tatiana
- * a bug fixed n www_dbsource
- *
- * Revision 4.9  1995/12/20  22:43:19  tatiana
- * Int2 changed to Int4 in www_organism()
- *
- * Revision 4.8  1995/12/19  23:34:20  tatiana
- * hot link to SGD added
- *
- * Revision 4.7  1995/12/13  16:36:15  tatiana
- * hot link to db_xref added
- *
- * Revision 4.6  1995/11/24  15:38:44  tatiana
- * GetAppParam moved to init_www
- *
- * Revision 4.5  1995/11/22  18:58:01  tatiana
- * turn spaces to + in hotlink
- *
- * Revision 4.4  1995/11/17  21:48:28  tatiana
- * hot link to genetic code added
- *
- * Revision 4.3  1995/11/17  21:28:35  kans
- * asn2ff now uses gather (Tatiana)
- *
- * Revision 1.10  1995/07/17  19:33:20  kans
- * parameters combined into Asn2ffJobPtr structure
- *
-*
-**************************************/
-
 
 #include <ncbi.h>
 #include <objsset.h>
@@ -2060,9 +1714,11 @@ static void LocPrintGenome(Asn2ffJobPtr ajp, GBEntryPtr gbp, SeqLocPtr slp_head)
 	10, /* 13 = ddbj */
 	10, /* 14 = prf */
 	12, /* 15 = pdb */
-        10,  /* 16 = tpg */
-        10,  /* 17 = tpe */
-        10   /* 18 = tpd */
+    10,  /* 16 = tpg */
+    10,  /* 17 = tpe */
+    10,  /* 18 = tpd */
+    10,  /* 19 = gpp */
+    10   /* 20 = nat */
     };
 	
 	Int2	l, ll;
