@@ -1,7 +1,7 @@
 #ifndef CONNECT___NCBI_ASSERT__H
 #define CONNECT___NCBI_ASSERT__H
 
-/*  $Id: ncbi_assert.h,v 1.2 2006/03/04 16:59:40 lavr Exp $
+/* $Id: ncbi_assert.h,v 1.4 2009/01/22 17:59:35 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -34,7 +34,7 @@
 
 #include "ncbi_config.h"
 
-#if defined(verify)
+#ifdef   verify
 #  undef verify
 #endif
 
@@ -45,26 +45,7 @@
 #if defined(NDEBUG)
 #  define verify(expr)  (void)(expr)
 #else
-#  ifdef NCBI_COMPILER_METROWERKS
-     /* The following 2 headers are only required for Codewarrior
-      * on Mac to prototype printf() and abort() respectively */
-#    include <stdio.h>
-#    include <stdlib.h>
-#  endif
 #  define verify(expr)  assert(expr)
 #endif
 
-
-/*
- * --------------------------------------------------------------------------
- * $Log: ncbi_assert.h,v $
- * Revision 1.2  2006/03/04 16:59:40  lavr
- * Formatting
- *
- * Revision 1.1  2005/04/20 18:11:23  lavr
- * Initial revision
- *
- * ==========================================================================
- */
-
 #endif /* CONNECT___NCBI_ASSERT__H */
