@@ -1,7 +1,7 @@
 #ifndef CONNECT___NCBI_CONNECTOR__H
 #define CONNECT___NCBI_CONNECTOR__H
 
-/*  $Id: ncbi_connector.h,v 6.16 2003/08/25 14:47:59 lavr Exp $
+/* $Id: ncbi_connector.h,v 6.18 2010/02/01 13:54:31 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -76,13 +76,16 @@ typedef const char* (*FConnectorGetType)
 
 /* Get the human readable connector's description (may be NULL on error)
  */
-typedef char* (*FConnectorDescr)
+typedef       char* (*FConnectorDescr)
 (CONNECTOR       connector
  );
 
 
 /* Open connection. Used to setup all related data structures,
  * but not necessarily has to actually open the data channel.
+ * NOTE: Regardless of the returned status, the connection is
+ *       considered open (so this call does not get repeated)
+ *       when the call completes.
  */
 typedef EIO_Status (*FConnectorOpen)
 (CONNECTOR       connector,
@@ -172,18 +175,15 @@ typedef EIO_Status (*FConnectorClose)
  * connectors are also here), part of connection handle("CONN").
  */
 typedef struct {
-    FConnectorGetType   get_type;    CONNECTOR c_get_type;
-    FConnectorDescr     descr;       CONNECTOR c_descr;
-    FConnectorOpen      open;        CONNECTOR c_open;
-    FConnectorWait      wait;        CONNECTOR c_wait;
-#ifdef IMPLEMENTED__CONN_WaitAsync
-    FConnectorWaitAsync wait_async;  CONNECTOR c_wait_async;
-#endif
-    FConnectorWrite     write;       CONNECTOR c_write;
-    FConnectorFlush     flush;       CONNECTOR c_flush;
-    FConnectorRead      read;        CONNECTOR c_read;
-    FConnectorStatus    status;      CONNECTOR c_status;
-    FConnectorClose     close;       CONNECTOR c_close;
+    FConnectorGetType   get_type; CONNECTOR c_get_type;
+    FConnectorDescr     descr;    CONNECTOR c_descr;
+    FConnectorOpen      open;     CONNECTOR c_open;
+    FConnectorWait      wait;     CONNECTOR c_wait;
+    FConnectorWrite     write;    CONNECTOR c_write;
+    FConnectorFlush     flush;    CONNECTOR c_flush;
+    FConnectorRead      read;     CONNECTOR c_read;
+    FConnectorStatus    status;   CONNECTOR c_status;
+    FConnectorClose     close;    CONNECTOR c_close;
     const STimeout*     default_timeout; /* default timeout pointer     */
     STimeout            default_tmo;     /* storage for default_timeout  */
     CONNECTOR           list;
@@ -194,19 +194,19 @@ typedef struct {
 
 #define CONN_SET_METHOD(meta, method, function, connector) \
     do {                                                   \
-        meta->method = function;                           \
+        meta->method                  = function;          \
         meta->CONN_TWO2ONE(c_,method) = connector;         \
-    } while (0);
+    } while (0)
 
 
 #define CONN_SET_DEFAULT_TIMEOUT(meta, timeout)            \
     do {                                                   \
         if (timeout) {                                     \
-            meta->default_timeout = &meta->default_tmo;    \
             meta->default_tmo     = *timeout;              \
+            meta->default_timeout = &meta->default_tmo;    \
         } else                                             \
-            meta->default_timeout = 0;                     \
-    } while (0);
+            meta->default_timeout = kInfiniteTimeout/*0*/; \
+    } while (0)
 
 
 /* Insert a connector in the beginning of the connection's list of connectors.
@@ -247,37 +247,14 @@ typedef void (*FDestroy)
 /* Connector specification.
  */
 typedef struct SConnectorTag {
-    void*                handle;    /* data handle of the connector */
-    CONNECTOR            next;      /* linked list                  */
-    SMetaConnector*      meta;      /* back link to CONNECTION      */
-    FSetupVTable         setup;     /* used in CONNECTION init      */
-    FDestroy             destroy;   /* destroys handle, can be NULL */
+    SMetaConnector* meta;     /* back link to CONNECTION      */
+    FSetupVTable    setup;    /* used in CONNECTION init      */
+    FDestroy        destroy;  /* destroys handle, can be NULL */
+    void*           handle;   /* data handle of the connector */
+    CONNECTOR       next;     /* linked list                  */
 } SConnector;
 
 
-#ifdef IMPLEMENTED__CONN_WaitAsync
-typedef struct {
-  CONN                   conn;
-  EIO_Event              event;
-  FConnAsyncHandler      handler;
-  void*                  data;
-  FConnAsyncCleanup      cleanup;
-} SConnectorAsyncHandler;
-
-typedef void (*FConnectorAsyncHandler)
-(SConnectorAsyncHandler* data,
- EIO_Event               event,
- EIO_Status              status
- );
-
-typedef EIO_Status (*FConnectorWaitAsync)
-(CONNECTOR               connector,
- FConnectorAsyncHandler  func,
- SConnectorAsyncHandler* data
- );
-#endif /* IMPLEMENTED__CONN_WaitAsync */
-
-
 #ifdef __cplusplus
 }  /* extern "C" */
 #endif
@@ -285,63 +262,4 @@ typedef EIO_Status (*FConnectorWaitAsync)
 
 /* @} */
 
-
-/*
- * --------------------------------------------------------------------------
- * $Log: ncbi_connector.h,v $
- * Revision 6.16  2003/08/25 14:47:59  lavr
- * Get rid of old ...TIMEOUT constants [now replaced with k...Timeout]
- *
- * Revision 6.15  2003/05/21 17:52:37  lavr
- * Pre- and post-conditions clarified for read and write virtual methods
- *
- * Revision 6.14  2003/05/14 03:47:53  lavr
- * +(*FConnectorDescr)()
- *
- * Revision 6.13  2003/04/09 17:58:45  siyan
- * Added doxygen support
- *
- * Revision 6.12  2003/01/08 01:59:32  lavr
- * DLL-ize CONNECT library for MSVC (add NCBI_XCONNECT_EXPORT)
- *
- * Revision 6.11  2002/09/19 18:00:11  lavr
- * Header file guard macro changed
- *
- * Revision 6.10  2002/09/06 15:40:54  lavr
- * More comments and notes to the API; log moved to end
- *
- * Revision 6.9  2002/04/26 16:29:32  lavr
- * Add default_timeout member to meta-connector
- *
- * Revision 6.8  2002/03/22 22:18:48  lavr
- * Cosmetic update
- *
- * Revision 6.7  2001/04/24 21:20:01  lavr
- * Introduced CONN_DEFAULT_TIMEOUT and CONN_INFINITE_TIMEOUT
- *
- * Revision 6.6  2001/03/02 20:07:18  lavr
- * Typos fixed
- *
- * Revision 6.5  2001/01/11 16:39:33  lavr
- * FDestroy function is now clearly documented not to destroy
- * the connector itself, only its handle (private internal data).
- *
- * Revision 6.4  2001/01/03 22:29:22  lavr
- * Changed IOStatus -> Status
- *
- * Revision 6.3  2000/12/29 17:45:07  lavr
- * Heavily modified to have a stack of connectors
- * VTable format changed; all virtual function now accept CONNECTOR as a
- * first argument (not void* as in previous versions)
- *
- * Revision 6.2  2000/04/07 19:59:49  vakatov
- * Moved forward-declaration of CONNECTOR from "ncbi_connection.h"
- * to "ncbi_connector.h"
- *
- * Revision 6.1  2000/03/24 22:52:48  vakatov
- * Initial revision
- *
- * ==========================================================================
- */
-
 #endif /* CONNECT___NCBI_CONNECTOR__H */
