@@ -1,7 +1,7 @@
 #ifndef CONNECT___NCBI_CORE__H
 #define CONNECT___NCBI_CORE__H
 
-/* $Id: ncbi_core.h,v 6.33 2007/10/17 15:25:43 kazimird Exp $
+/* $Id: ncbi_core.h,v 6.38 2011/04/17 02:39:31 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -86,13 +86,14 @@ extern "C" {
  *  EIO_WriteMethod
  */
 typedef enum {
-    eIO_ReadPlain,   /**< read presently available data only                 */
-    eIO_ReadPeek,    /**< same eIO_ReadPlain but leave data in input queue   */
-    eIO_ReadPersist, /**< try to read exactly "n" bytes; wait for enough data*/
-    /* deprecated */
-    eIO_Plain   = eIO_ReadPlain,
-    eIO_Peek    = eIO_ReadPeek,
-    eIO_Persist = eIO_ReadPersist
+    eIO_ReadPlain,      /**< read readily available data only, wait if none  */
+    eIO_ReadPeek,       /**< do eIO_ReadPlain but leave data in input queue  */
+    eIO_ReadPersist,    /**< read exactly as much as requested, w/waits      */
+    eIO_ReadSupplement  /**< do eIO_ReadPlain but return extended status     */
+    /* deprecated -- DO NOT USE! */
+    /*eIO_Plain   = eIO_ReadPlain,*/
+    /*eIO_Peek    = eIO_ReadPeek,*/
+    /*eIO_Persist = eIO_ReadPersist*/
 } EIO_ReadMethod;
 
 
@@ -101,17 +102,18 @@ typedef enum {
  *  EIO_ReadMethod
  */
 typedef enum {
-    eIO_WritePlain,    /**< write as much as possible, report back how much  */
-    eIO_WritePersist,  /**< write exactly as much as specified               */
-    eIO_WriteOutOfBand /**< write out-of-band chunk of urgent data           */
+    eIO_WritePlain,     /**< write as much as possible, report back how much */
+    eIO_WritePersist,   /**< write exactly as much as specified              */
+    eIO_WriteOutOfBand, /**< write out-of-band chunk of urgent data          */
+    eIO_WriteSupplement /**< do eIO_WritePlain but return extended status    */
 } EIO_WriteMethod;
 
 
 /** I/O event (or direction).
  * @par <b>NOTE:</b>
  *  Internally, these constants are used as bit-values,
- *  and thus should not be changed in this header.  However, user code
- *  should not rely on the values of these constants.
+ *  and thus should not be changed in this header.  On the other hand,
+ *  user code should not rely on the values of these constants, either.
  * @sa
  *  SOCK_Wait, SOCK_Poll, CONN_Wait, SOCK_SetTimeout, CONN_SetTimeout
  */
@@ -120,20 +122,19 @@ typedef enum {
     eIO_Read      = 0x1,
     eIO_Write     = 0x2,
     eIO_ReadWrite = 0x3, /**< eIO_Read | eIO_Write                           */
-    eIO_Close     = 0x4  /**< also serves as error indicator in SOCK_Poll    */
+    eIO_Close     = 0x4  /**< also serves as an error indicator in SOCK_Poll */
 } EIO_Event;
 
 
 /** I/O status.
  */
 typedef enum {
-    eIO_Success = 0,  /**< everything is fine, no errors occurred            */
+    eIO_Success = 0,  /**< everything is fine, no error occurred             */
     eIO_Timeout,      /**< timeout expired before any I/O succeeded          */
     eIO_Closed,       /**< peer has closed the connection                    */
-    eIO_Interrupt,    /**< signal received while an I/O was in progress      */
+    eIO_Interrupt,    /**< signal received while I/O was in progress         */
     eIO_InvalidArg,   /**< bad argument value(s)                             */
     eIO_NotSupported, /**< the requested operation is not supported          */
-
     eIO_Unknown       /**< unknown (most probably -- fatal) error            */
 } EIO_Status;
 
@@ -156,6 +157,13 @@ extern NCBI_XCONNECT_EXPORT const char* IO_StatusStr(EIO_Status status);
 
 
 /** Lock handle -- keeps all data needed for the locking and for the cleanup.
+ * The following are the minimal requirements for the lock:
+ * - if lock for read is available, then the lock must allow one nested lock
+ * for read when it has been already locked for write (naturally, by the
+ * same thread);
+ * - if lock for read is not available (i.e. the read lock is implemented
+ * as a write lock), the lock must allow recursive locking (by the same
+ * thread) of the depth of 2.
  */
 struct MT_LOCK_tag;
 typedef struct MT_LOCK_tag* MT_LOCK;
@@ -176,7 +184,7 @@ typedef enum {
 } EMT_Lock;
 
 
-/** MT locking callback (operates like a mutex or RW-lock).
+/** MT locking callback (operates like a [recursive] mutex or RW-lock).
  * @param user_data
  *  See "user_data" in MT_LOCK_Create()
  * @param how
@@ -257,7 +265,7 @@ extern NCBI_XCONNECT_EXPORT MT_LOCK MT_LOCK_Delete(MT_LOCK lk);
  * @sa
  *  MT_LOCK_Create, FMT_LOCK_Handler, EMT_Lock
  */
-#define MT_LOCK_Do(lk, how)  (lk ? MT_LOCK_DoInternal(lk, how) : -1)
+#define MT_LOCK_Do(lk, how)  ((lk) ? MT_LOCK_DoInternal((lk), (how)) : -1)
 extern NCBI_XCONNECT_EXPORT int/*bool*/ MT_LOCK_DoInternal
 (MT_LOCK  lk,
  EMT_Lock how
@@ -299,6 +307,8 @@ extern NCBI_XCONNECT_EXPORT const char* LOG_LevelStr(ELOG_Level level);
 
 
 /** Message and miscellaneous data to pass to log post callback FLOG_Handler.
+ * @param dynamic
+ *  if non-zero then LOG_WriteInternal() will call free(message) before return
  * @param message
  *  A message to post, can be NULL
  * @param level
@@ -318,13 +328,14 @@ extern NCBI_XCONNECT_EXPORT const char* LOG_LevelStr(ELOG_Level level);
  * @param err_subcode
  *  Error subcode of the message
  * @sa
- *  FLOG_Handler, LOG_Create, LOG_WriteInternal
+ *  FLOG_Handler, LOG_Create, LOG_WriteInternal, LOG_Write
  */
 typedef struct {
+    int/*bool*/ dynamic;
     const char* message;
     ELOG_Level  level;
-    const char* module;  
-    const char* file;  
+    const char* module;
+    const char* file;
     int         line;
     const void* raw_data;
     size_t      raw_size;
@@ -395,10 +406,12 @@ extern NCBI_XCONNECT_EXPORT LOG LOG_Create
  *  New log post callback
  * @param cleanup
  *  New cleanup callback
+ * @return
+ *  lg (as passed in the first parameter)
  * @sa
  *  LOG_Create
  */
-extern NCBI_XCONNECT_EXPORT void LOG_Reset
+extern NCBI_XCONNECT_EXPORT LOG LOG_Reset
 (LOG          lg,     
  void*        user_data,
  FLOG_Handler handler,
@@ -426,13 +439,31 @@ extern NCBI_XCONNECT_EXPORT LOG LOG_AddRef(LOG lg);
 extern NCBI_XCONNECT_EXPORT LOG LOG_Delete(LOG lg);
 
 
-/** Write message (perhaps with raw data attached) to the log by doing
- * "lg->handler(lg->user_data, SLOG_Handler*)".
+/** Write message (perhaps with raw data attached) to the log by calling
+ * "lg->handler(lg->user_data, call_data)".
  * @par <b>NOTE:</b>
  *  Do not call this function directly, if possible.
  *  Instead, use LOG_WRITE() and LOG_DATA() macros from <ncbi_util.h>!
  * @param lg
  *  A log handle previously obtained from LOG_Create
+ * @sa
+ *  LOG_Create, ELOG_Level, FLOG_Handler, LOG_WRITE, LOG_DATA
+ */
+extern NCBI_XCONNECT_EXPORT void LOG_WriteInternal
+(LOG           lg,
+ SLOG_Handler* call_data
+ );
+
+
+/** Write message (perhaps with raw data attached) to the log by calling
+ * LOG_WriteInternal() upon filling up SLOG_Handler data from parameters.
+ * @par <b>NOTE:</b>
+ *  Do not call this function directly, if possible.
+ *  Instead, use LOG_WRITE() and LOG_DATA() macros from <ncbi_util.h>!
+ * @param code
+ *  Error code of the message
+ * @param subcode
+ *  Error subcode of the message
  * @param level
  *  The message severity
  * @param module
@@ -447,28 +478,23 @@ extern NCBI_XCONNECT_EXPORT LOG LOG_Delete(LOG lg);
  *  Raw data to log (can be NULL)
  * @param raw_size
  *  Size of the raw data (can be zero)
- * @param err_code
- *  Error code of the message
- * @param err_subcode
- *  Error subcode of the message
  * @sa
- *  LOG_Create, ELOG_Level, FLOG_Handler, LOG_WRITE, LOG_DATA
+ *  LOG_Create, ELOG_Level, FLOG_Handler, LOG_WriteInternal
  */
-extern NCBI_XCONNECT_EXPORT void LOG_WriteInternal
+extern NCBI_XCONNECT_EXPORT void LOG_Write
 (LOG         lg,   
+ int         code,
+ int         subcode,
  ELOG_Level  level,
  const char* module,
  const char* file, 
- int         line,  
+ int         line,
  const char* message,
  const void* raw_data,
- size_t      raw_size,
- int         err_code,
- int         err_subcode
+ size_t      raw_size
 );
 
 
-
 /******************************************************************************
  *  REGISTRY
  */
@@ -533,11 +559,13 @@ typedef void (*FREG_Get)
  * @param value
  *  Key value to associate with the key
  * @param storage
- *  How to store the new setting, temporarily or permanently.
+ *  How to store the new setting, temporarily or permanently
+ * @return
+ *  Non-zero if successful (including replacing a value with itself)
  * @sa
  *  REG_Create, REG_Reset, EREG_Storage
  */
-typedef void (*FREG_Set)
+typedef int (*FREG_Set)
 (void*        user_data,
  const char*  section,
  const char*  name,
@@ -563,6 +591,8 @@ typedef void (*FREG_Cleanup)
  *  MT_LOCK_Delete() will be called on it when this REG gets destroyed
  *  -- be aware of it (hence, if the lock is also to be used with something
  *  else, then call MT_LOCK_AddRef() on it before passing to REG_Create)!
+ * Passing NULL callbacks below causes limiting the functionality
+ * only to those operations that have the callbacks set.
  * @param user_data
  *  Unspecified data to call "set", "get" and "cleanup" with 
  * @param get
@@ -658,7 +688,7 @@ extern NCBI_XCONNECT_EXPORT REG REG_Delete(REG rg);
  * @sa
  *  REG_Create, REG_Set
  */
-extern NCBI_XCONNECT_EXPORT char* REG_Get
+extern NCBI_XCONNECT_EXPORT const char* REG_Get
 (REG         rg, 
  const char* section,
  const char* name,
@@ -680,10 +710,12 @@ extern NCBI_XCONNECT_EXPORT char* REG_Get
  *  The value to store
  * @param storage
  *  Whether to store temporarily or permanently
+ * @return
+ *  Non-zero if successful (including replacing a value with itself)
  * @sa
  *  REG_Create, EREG_Storage, REG_Get
  */
-extern NCBI_XCONNECT_EXPORT void REG_Set
+extern NCBI_XCONNECT_EXPORT int REG_Set
 (REG          rg,
  const char*  section,
  const char*  name,
