@@ -1,4 +1,4 @@
-/* $Id: ncbi_dispd.c,v 6.93 2009/02/04 19:29:34 kazimird Exp $
+/* $Id: ncbi_dispd.c,v 6.95 2011/05/26 19:14:35 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -144,7 +144,7 @@ extern "C" {
 /*ARGSUSED*/
 static int/*bool*/ s_Adjust(SConnNetInfo* net_info,
                             void*         iter,
-                            unsigned int  n)
+                            unsigned int  unused)
 {
     struct SDISPD_Data* data = (struct SDISPD_Data*)((SERV_ITER) iter)->data;
     return data->fail ? 0/*no more tries*/ : 1/*may try again*/;
@@ -180,8 +180,8 @@ static void s_Resolve(SERV_ITER iter)
                                        : !net_info->stateless
                                        ? "Client-Mode: STATEFUL_CAPABLE\r\n"
                                        : "Client-Mode: STATELESS_ONLY\r\n")) {
-        conn = HTTP_CreateConnectorEx(net_info, fHCC_SureFlush, s_ParseHeader,
-                                      s_Adjust, iter/*data*/, 0/*cleanup*/);
+        conn = HTTP_CreateConnectorEx(net_info, fHTTP_SureFlush, s_ParseHeader,
+                                      iter/*data*/, s_Adjust, 0/*cleanup*/);
     }
     if (s) {
         ConnNetInfo_DeleteUserHeader(net_info, s);
@@ -261,7 +261,7 @@ static int/*bool*/ s_Update(SERV_ITER iter, const char* text, int code)
             while (*text  &&  isspace((unsigned char)(*text)))
                 text++;
             CORE_LOGF_X(2, failure ? eLOG_Warning : eLOG_Note,
-                        ("[%s]  %s", data->net_info->service, text));
+                        ("[%s]  %s", data->net_info->svc, text));
         }
 #endif /*_DEBUG && !NDEBUG*/
         if (failure) {
