@@ -1,7 +1,7 @@
 #ifndef CONNECT___NCBI_UTIL__H
 #define CONNECT___NCBI_UTIL__H
 
-/* $Id: ncbi_util.h,v 6.38 2008/12/01 16:34:35 kazimird Exp $
+/* $Id: ncbi_util.h,v 6.44 2011/02/17 18:09:33 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -50,8 +50,9 @@
  *       CORE_GetUsername()
  *       CORE_GetVMPageSize()
  *
- * 3. CRC32 support:
- *       CRC32_Update()
+ * 3. Checksumming support:
+ *       UTIL_CRC32_Update()
+ *       UTIL_Adler32_Update()
  *
  * 4. Miscellaneous:
  *       UTIL_MatchesMask[Ex]()
@@ -173,7 +174,7 @@ extern NCBI_XCONNECT_EXPORT void CORE_SetLOGFILE_Ex
 
 
 /** Same as CORE_SetLOGFILE_Ex() with last parameter passed as 0
- * (all messages pass).
+ * (all messages get posted).
  * @sa
  *   CORE_SetLOGFILE_Ex, CORE_SetLOG
  */
@@ -215,10 +216,9 @@ extern NCBI_XCONNECT_EXPORT int/*bool*/ CORE_SetLOGFILE_NAME
  */
 typedef enum {
     fLOG_Default       = 0x0,    /**< fLOG_Short if NDEBUG, else fLOG_Full   */
-
     fLOG_Level         = 0x1,
     fLOG_Module        = 0x2,
-    fLOG_FileLine      = 0x4,    /**< always here for eLOG_Trace level       */
+    fLOG_FileLine      = 0x4,
     fLOG_DateTime      = 0x8,
     fLOG_FullOctal     = 0x2000, /**< do not do reduction in octal data bytes*/
     fLOG_OmitNoteLevel = 0x4000, /**< do not add NOTE if eLOG_Note is level  */
@@ -305,7 +305,7 @@ extern NCBI_XCONNECT_EXPORT void LOG_ToFILE
  *  LOG_ComposeMessage
  */
 extern NCBI_XCONNECT_EXPORT const char* NcbiMessagePlusError
-(int*/*bool*/ dynamic,
+(int/*bool*/ *dynamic,
  const char*  message,
  int          error,
  const char*  descr
@@ -384,6 +384,17 @@ extern NCBI_XCONNECT_EXPORT REG  CORE_GetREG(void);
 extern NCBI_XCONNECT_EXPORT const char* CORE_GetPlatform(void);
 
 
+/** Obtain current application name (toolkit dependent).
+ * @return
+ *  Return 0 when the application name cannot be determined;
+ *  otherwise, return a NULL-terminated string
+ *
+ * NOTE that setting an application name concurrently with this
+ * call can cause undefined behavior or a stale pointer returned.
+ */
+extern NCBI_XCONNECT_EXPORT const char* CORE_GetAppName(void);
+
+
 /** Obtain and store current user's name in the buffer provided.
  * Note that resultant strlen(buf) is always guaranteed to be less
  * than "bufsize", extra non-fit characters discarded.
@@ -397,8 +408,8 @@ extern NCBI_XCONNECT_EXPORT const char* CORE_GetPlatform(void);
  *  otherwise, return "buf".
  */
 extern NCBI_XCONNECT_EXPORT const char* CORE_GetUsername
-(char*        buf,
- size_t       bufsize
+(char*  buf,
+ size_t bufsize
  );
 
 
@@ -414,23 +425,45 @@ extern NCBI_XCONNECT_EXPORT size_t CORE_GetVMPageSize(void);
  *  CRC32
  */
 
-/** Calculate/Update CRC32
+/** Calculate/Update CRC-32 checksum
+ * NB:  Initial checksum is "0".
  * @param checksum
  *  Checksum to update (start with 0)
  * @param ptr
  *  Block of data
- * @param count
- *  Size of data
+ * @param len
+ *  Size of block of data
  * @return
  *  Return the checksum updated according to the contents of the block
- *  pointed to by "ptr" and having "count" bytes in it.
+ *  pointed to by "ptr" and having "len" bytes in it.
  */
-extern NCBI_XCONNECT_EXPORT unsigned int CRC32_Update
+extern NCBI_XCONNECT_EXPORT unsigned int UTIL_CRC32_Update
 (unsigned int checksum,
  const void*  ptr,
- size_t       count
+ size_t       len
  );
 
+/* FIXME: Compatibility (to remove in the future) */
+#define CRC32_Update(c, p, l)  UTIL_CRC32_Update(c, p, l)
+
+
+/** Calculate/Update Adler-32 checksum
+ * NB:  Initial checksum is "1".
+ * @param checksum
+ *  Checksum to update (start with 1)
+ * @param ptr
+ *  Block of data
+ * @param len
+ *  Size of block of data
+ * @return
+ *  Return the checksum updated according to the contents of the block
+ *  pointed to by "ptr" and having "len" bytes in it.
+ */
+extern NCBI_XCONNECT_EXPORT unsigned int UTIL_Adler32_Update
+(unsigned int checksum,
+ const void*  ptr,
+ size_t       len
+ );
 
 
 /******************************************************************************
@@ -467,8 +500,8 @@ extern NCBI_XCONNECT_EXPORT int/*bool*/ UTIL_MatchesMask
  *  Hostname to shorten (if possible)
  * @return 0 if the hostname wasn't modified, otherwise return "hostname".
  */
-extern char* UTIL_NcbiLocalHostName
-(char*       hostname
+extern NCBI_XCONNECT_EXPORT char* UTIL_NcbiLocalHostName
+(char* hostname
  );
 
 
@@ -482,7 +515,7 @@ extern char* UTIL_NcbiLocalHostName
  * @return the buffer size needed (0 for NULL or empty (size==0) block).
  * @sa UTIL_PrintableString
  */
-extern size_t UTIL_PrintableStringSize
+extern NCBI_XCONNECT_EXPORT size_t UTIL_PrintableStringSize
 (const char* data,
  size_t      size
  );
@@ -509,7 +542,7 @@ extern size_t UTIL_PrintableStringSize
  * @return next position in the buffer past the last stored character.
  * @sa UTIL_PrintableStringSize
  */
-extern char* UTIL_PrintableString
+extern NCBI_XCONNECT_EXPORT char* UTIL_PrintableString
 (const char* data,
  size_t      size,
  char*       buf,
@@ -517,6 +550,34 @@ extern char* UTIL_PrintableString
  );
 
 
+/**
+ *  Conversion from Unicode to UTF8, and back.
+ *  Microsoft Windows - specific.
+ *  NOTE:
+ *    The caller should use UTIL_ReleaseBufferOnHeap function
+ *    to free the buffer returned from UTIL_TcharToUtf8OnHeap;
+ *    and ReleaseBuffer to free the one returned from UTIL_TcharToUtf8
+ */
+
+#if defined(NCBI_OS_MSWIN)  &&  defined(_UNICODE)
+extern const char*    UTIL_TcharToUtf8OnHeap(const wchar_t* buffer);
+extern const char*    UTIL_TcharToUtf8      (const wchar_t* buffer);
+extern const wchar_t* UTIL_Utf8ToTchar      (const    char* buffer);
+#  define             UTIL_ReleaseBuffer(x)  UTIL_ReleaseBufferOnHeap(x)
+#else
+#  define             UTIL_TcharToUtf8OnHeap(x)  (x)
+#  define             UTIL_TcharToUtf8(x)        (x)
+#  define             UTIL_Utf8ToTchar(x)        (x)
+#  define             UTIL_ReleaseBuffer(x)      /*void*/
+#endif /*NCBI_OS_MSWIN && _UNICODE*/
+
+#ifdef NCBI_OS_MSWIN
+extern void           UTIL_ReleaseBufferOnHeap(const void* buffer);
+#else
+#  define             UTIL_ReleaseBufferOnHeap(x)  /*void*/
+#endif /*NCBI_OS_MSWIN*/
+
+
 #ifdef __cplusplus
 }  /* extern "C" */
 #endif
