@@ -2,7 +2,7 @@
 #define UTIL_CREADERS___ALNREAD__H
 
 /*
- * $Id: alnread.h,v 1.4 2004/11/24 15:26:18 dicuccio Exp $
+ * $Id: alnread.h,v 1.7 2006/09/14 13:31:00 bollin Exp $
  *
  * ===========================================================================
  *
@@ -100,7 +100,7 @@ typedef struct SSequenceInfo {
     char * beginning_gap;
     char * middle_gap;
     char * end_gap;
-    char * alphabet;
+    const char * alphabet;
 } SSequenceInfo, * TSequenceInfoPtr;
 
 extern NCBI_CREADERS_EXPORT TSequenceInfoPtr SequenceInfoNew (void);
@@ -115,6 +115,7 @@ typedef struct SAlignmentFile {
     char ** sequences;
     char ** organisms;
     char ** deflines;
+    char    align_format_found;
 } SAlignmentFile, * TAlignmentFilePtr;
 
 extern NCBI_CREADERS_EXPORT TAlignmentFilePtr AlignmentFileNew (void);
@@ -136,6 +137,27 @@ extern NCBI_CREADERS_EXPORT TAlignmentFilePtr ReadAlignmentFile (
                                        */
 );
 
+extern NCBI_CREADERS_EXPORT TAlignmentFilePtr ReadAlignmentFileEx (
+  FReadLineFunction    readfunc,      /* function for reading lines of 
+                                       * alignment file
+                                       */
+  void *               fileuserdata,  /* data to be passed back each time
+                                       * readfunc is invoked
+                                       */
+  FReportErrorFunction errfunc,       /* function for reporting errors */
+  void *               erroruserdata, /* data to be passed back each time
+                                       * errfunc is invoked
+                                       */
+  TSequenceInfoPtr     sequence_info, /* structure containing sequence
+                                       * alphabet and special characters
+                                       */
+  int                  use_nexus_file_info /* set to nonzero to replace data in 
+                                            * sequence_info with characters
+                                            * read from NEXUS comment in file,
+                                            * set to 0 otherwise.
+                                            */
+);
+
 #ifdef __cplusplus
 }
 #endif
@@ -144,6 +166,16 @@ extern NCBI_CREADERS_EXPORT TAlignmentFilePtr ReadAlignmentFile (
  * ==========================================================================
  *
  * $Log: alnread.h,v $
+ * Revision 1.7  2006/09/14 13:31:00  bollin
+ * make alphabet in SequenceInfo struct const
+ *
+ * Revision 1.6  2006/09/13 18:34:41  bollin
+ * added flag to indicate whether alignment formatting clues were found
+ *
+ * Revision 1.5  2005/10/21 15:18:36  bollin
+ * added function to allow the gap, missing, and match characters to be read
+ * from NEXUS comments for an alignment
+ *
  * Revision 1.4  2004/11/24 15:26:18  dicuccio
  * Swap extern and export specifier; white space changes
  *
